import { useState, useEffect, useRef } from 'react'
import withLayout from '@/layout'
import { ScrollView } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_CLIENT_LIST, API_CHANNEL_CLIENT_LIST } from '@/constants/api'
import { ROLE_CODE } from '@/constants/user'
import './index.scss'
import MyCustomerListItem from '../components/MyCustomerListItem/index'
import TypePicker from './TypePicker'

export default withLayout((props) => {
  const { person } = props
  const [PageList, setPageList] = useState([])
  const [IsPull, setPull] = useState(false)
  const [pageNumber, setPageNumber] = useState(1)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [bizType, setBizType] = useState('')
  const GetPageList = useRef()

  GetPageList.current = () => {
    setHasNextPage(false)
    const url = ROLE_CODE.CHANNEL_AGENT === person.personType ? API_CHANNEL_CLIENT_LIST : API_CLIENT_LIST
    fetch({ url, payload: { pageNumber, pageSize: 10 } }).then((res) => {
      setPageList(pageNumber === 1 ? res.records || [] : PageList.concat(res.records || []))
      setHasNextPage(res.current < res.pages)
      setPull(false)
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  const PageLoadMore = () => { // 页面上拉加载更多
    if(HasNextPage) {
      setPageNumber(pageNumber + 1)
    }
  }

  useEffect(() => {
    GetPageList.current()
  }, [pageNumber])

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      if(pageNumber === 1) {
        GetPageList.current()
      } else {
        setPageNumber(1)
      }
    }
  }, [IsPull])

  return (
    <view className='Page myCustomer flex-v'>

      <view className='Filter'>
        <view className='flex-h'>
          <view className='Time'>
            <text>全部时间</text>
            <text className='iconfont icon-sanjiaoxingdown'></text>
          </view>
          <view className='Type'>
            <TypePicker value={bizType} onChange={setBizType} />
            <text className='iconfont icon-sanjiaoxingdown'></text>
          </view>
          <view className='flex-item'></view>
          <text className='iconfont icon-sousuo'></text>
        </view>
      </view>

      <view className='flex-item'>
        <view>

          <ScrollView scroll-y refresher-enabled refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} onscrolltolower={PageLoadMore} refresher-background='#fff'>
            <view className='PageContent'>
              <view className='List'>
                {
                  PageList.map((item, index) => (
                    <view>
                      <MyCustomerListItem data={item} key={`MyCustomerListItem-${index}`}></MyCustomerListItem>
                    </view>
                  ))
                }
              </view>

              {/* bottom */}
              <view className='PageBottom'>
                <text>已经到底了~</text>
              </view>

            </view>
          </ScrollView>
        </view>
      </view>

    </view>
  )
})
